@@ -1,7 +1,7 @@
 #%%
 from re import L
-from cosmoglobe.plot.plottools import standalone_colorbar, seds_from_model, symlog
-from cosmoglobe.plot import plot, gnom, trace, spec
+from cosmoglobe.plot.plottools import standalone_colorbar, seds_from_model, symlog, fmt
+from cosmoglobe.plot import plot, gnom, trace, spec, hist
 from cosmoglobe.sky import model_from_chain
 from cosmoglobe.h5.chain import Chain
 from cosmoglobe import get_test_chain
@@ -10,7 +10,9 @@ import numpy as np
 import healpy as hp 
 import astropy.units as u
 import matplotlib.pyplot as plt
+import matplotlib.colors as colors
 from matplotlib.colors import colorConverter, LinearSegmentedColormap, ListedColormap
+from matplotlib.ticker import FuncFormatter, LogLocator, LogFormatter, LogFormatterExponent, LogFormatterMathtext
 import os
 from pathlib import Path
 import data as data_dir
@@ -23,7 +25,7 @@ planck_cmap = ListedColormap(planck_cmap, "planck")
 
 paperfigs='/Users/svalheim/work/BP/papers/09_leakage/figs2/'
 path='/Users/svalheim/work/cosmoglobe-workdir/'
-#chain='bla.h5'
+chain='example_reduced.h5'
 dust='dust_c0001_k000200.fits'
 cmb='cmb_c0001_k000200.fits'
 
@@ -90,11 +92,18 @@ if False:
         else:
             components.append(comps[i])
 
+
+if False:
+    data = np.random.rand(50, 2)
+    trace(data, labels=["Test 1","Test 2",], )
+    plt.show()
+
 if False:
     chain=get_test_chain()
-    model = model_from_chain(chain, components=["synch", "cmb"], nside=64)
-    spec(model,pol=True,)
-    plt.savefig(f"spectrum_synch.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
+    model = model_from_chain(chain, components=["synch", "cmb","dust","ame","ff"], nside=64)
+    spec(model,)
+    plt.show()
+    #plt.savefig(f"spectrum_synch.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
 
 if False:
     model = model_from_chain(path+chain, components=["dust"], nside=16)
@@ -122,27 +131,6 @@ if False:
         ytick_label_color="white",)#fwhm=14*u.arcmin, darkmode=True)
     plt.show()
 
-# m 4.7 = 0.07
-# l 7   = 0.04
-#0.07=4.7*(0.07-0.04)/(4.7-7)
-
-
-
-#ratio = ratio_l*width/width_l
-#ratio = 0.04*width/7
-
-#0.04x = 0.07
-#7     = 4.7   
-
-#ratio_y = l
-#ratio = width/7*0.04
-
-if False: #simplest
-    plot(path+dust, width="m", sig="Q",comp="dust",norm="log")
-    plt.show()
-    #plt.savefig("testm.png", dpi=600, pad_inches = 0, bbox_inches="tight")
-    #plot(path+dust, width="s", sig="Q",comp="dust", title="title")
-    #plt.savefig("tests.png", dpi=600)
 
 if False:
     plot(path+dust, interactive=True, sig="Q", ticks=[0, np.pi, None], norm="log", unit=u.uK, fwhm=14*u.arcmin, nside=512, cmap="chroma", left_label="Left", right_label="Right", title="Cool figure", width=7, graticule=True, projection_type="hammer", mask=path+"mask_common_dx12_n0512_TQU.fits", maskfill="pink", graticule_color="white", xtick_label_color="white", ytick_label_color="white",)# darkmode=True)
@@ -175,9 +163,11 @@ if False:
 if False:
     #c = Chain(path+chain)
     #print(c["000001/tod/023-WMAP_K/chisq"])
-    trace(path+chain, figsize=(10,2), sig=0, labels=["Reg1","Reg2","Reg3","Reg4"], dataset="synch/beta_pixreg_val", subplot=(3,1,1), ylabel=r"$\beta_s^T$")
-    trace(path+chain, sig=1, labels=["Reg1","Reg2","Reg3","Reg4"], dataset="synch/beta_pixreg_val", subplot=(3,1,2), ylabel=r"$\beta_s^P$")
-    trace(path+chain, dataset="tod/023-WMAP_K/bp_delta", subplot=(3,1,3), ylabel=r"$\Delta_{bp}$")
+    hist(path+cmb,range=(-5000,5000),bins=50)
+    plt.tight_layout()
+    #trace(path+chain, figsize=(10,2), sig=0, labels=["Reg1","Reg2","Reg3","Reg4"], dataset="synch/beta_pixreg_val", subplot=(3,1,1), ylabel=r"$\beta_s^T$")
+    #trace(path+chain, sig=1, labels=["Reg1","Reg2","Reg3","Reg4"], dataset="synch/beta_pixreg_val", subplot=(3,1,2), ylabel=r"$\beta_s^P$")
+    #trace(path+chain, dataset="tod/023-WMAP_K/bp_delta", subplot=(3,1,3), ylabel=r"$\Delta_{bp}$")
     #trace(path+chain, dataset="tod/023-WMAP_K/chisq", subplot=(5,1,4), ylabel=r"$\chi^2$")
     #trace(path+chain, dataset="tod/023-WMAP_K/gain", subplot=(5,1,5), ylabel="gain", xlabel="Gibbs sample")
     plt.show()
@@ -242,88 +232,153 @@ if False:
 
         fsky = hp.remove_dipole(sky(freq*u.GHz,)[0].value, gal_cut=30, copy=True)
         fcmb = hp.remove_dipole(cmb(freq*u.GHz,)[0].value, gal_cut=30, copy=True)
-        ftot = fcmb + fsky*s
+        fsky[fsky<0] = 0.0
+        ftot = fcmb + (fsky)*s
+        #plt.show()
+        number = i+1 #str(i+1).zfill(3)
+        plot(fsky*s, ticks=[10, 100], norm="log", cmap="binary", cbar=False, width=1)
+        plt.savefig(f"/Users/svalheim/work/thesis/figures/gifs/smallgif_{number}.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
 
-        #plot(fsky, ticks=[-1e3, -100, 0, 100, 1e3, 1e7], cmap="planck_log", title=f'{freq:.0f} GHz', remove_mono=True, cbar=False, width=1)
-        plot(fsky, ticks=[10, 100], norm="log", cmap="binary", remove_mono=True, cbar=False, width=1)
-        #plot(ftot, ticks=[-1e3, -100, 0, 100, 1e3, 1e7], cmap="planck_log", remove_mono=True, cbar=False, width=1,fwhm=120*u.arcmin)
-        plt.savefig(f"/Users/svalheim/work/thesis/figures/gifs/smallgif_{i+1}.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
+        plot(ftot, ticks=[-1e3, -100, 0, 100, 1e3, 1e7], cmap="planck_log", cbar=False, width=1, fwhm=180*u.arcmin)
+        #plt.show()
+        plt.savefig(f"/Users/svalheim/work/thesis/figures/gifs/smallgifcolor_{number}.png", bbox_inches='tight',  pad_inches=0.02, transparent=True, dpi=300)
+
+if False:
+    import h5py
+
+
+    def real_2_alm(rlm, lmax, mmax):
+        cx_alm = np.zeros(mmax * (2 * lmax + 1 - mmax) // 2 + lmax + 1, dtype="complex")
+
+        for l in range(0, lmax):
+            for m in range(0, mmax):
+                if m > l:
+                    continue
+                healpixI = hp.sphtfunc.Alm.getidx(lmax, l, m)
+                outI = getOutidx(l, m)
+                outJ = getOutidx(l, -1 * m)
+                if m == 0:
+                    cx_alm[healpixI] = rlm[outI]
+                else:
+                    cx_alm[healpixI] = (rlm[outI] + 1j * rlm[outJ]) / 2 ** 0.5
+
+        return cx_alm
+
+
+    def getOutidx(l, m):
+        return l ** 2 + l + m
+
+
+    def main(
+        rot=0, nside_planck=4096,
+    ):
+        # According to the BP overview paper, the Planck beams are normalized such that
+        # their integral combined is equal to unity.
+        path="./"
+        path="/Users/svalheim/work/workdir-thesis/beams/"
+        data = h5py.File(path+"LFI_instrument_v6.h5", "r")
+
+        blm = data["27M/beam/T"][...]
+        blmax = data["27M/beamlmax"][...]
+        bmmax = data["27M/beammmax"][...]
+
+        slm = data["27M/sl/T"][...]
+        slmax = data["27M/sllmax"][...]
+        smmax = data["27M/slmmax"][...]
+
+        cx_alm = real_2_alm(slm, slmax[0], smmax[0])
+        # s_lp = hp.alm2cl(cx_alm, lmax=slmax[0], mmax=smmax[0]) ** 0.5 * (4 * np.pi) ** 0.5
+        m = hp.alm2map(cx_alm, nside_planck, lmax=slmax[0], mmax=smmax[0])
+        m[m <= 0] = min(abs(m))
+
+        arcmin2rad=0.000290888
+        cx_alm = real_2_alm(blm, blmax[0], bmmax[0])
+        m1 = hp.alm2map(cx_alm, nside_planck, lmax=blmax[0], mmax=bmmax[0])
+        m1 = hp.smoothing(m1, fwhm=180*arcmin2rad)
+        #m1[m1<0] = min(abs(m1))
+        m1[m1<=1e-2] = min(abs(m1))
+
+        #hp.mollview(m,  rot=(0, 90, 0), norm="log", min=1e-5, max=5e-2, cmap="afmhot", title="27S Beam sidelobes")
+        #hp.mollview(m1, rot=(0, 90, 0), min=0,  cmap="afmhot", title="main beam")
+        #hp.gnomview(m1, rot=(0, 90, 0), reso=0.75, min=0, max=1, cmap="afmhot", title="Main beam")
+        #hp.mollview(m + m1, rot=(0, 90, 0), min=1e-5, max=1000, norm="log", cmap="afmhot", title="combined beams")
+        #plot(np.log10(m + m1), rot=(0, 90, 0), min=-5, max=3, cmap="afmhot",)
+        plot(m + m1, rot=(0, 90, 0), ticks=[1e-4, 1, 1e4], norm="log", cmap="afmhot", width="s")
+        color="#fefedc"
+        color="white"
+        alpha = 0.5
+        from matplotlib.patches import Ellipse
+        import matplotlib.patheffects as path_effects
+        el = Ellipse((2, -1), 0.5, 0.5)
+        arrowprops = dict(facecolor=color, shrink=0.05)
+        arrowprops = dict(arrowstyle="wedge,tail_width=0.7",
+                                fc=color, ec="none",
+                                patchB=el,
+                                connectionstyle="arc3,rad=-0.3")
+        arrowprops = dict(arrowstyle="-", color=color,alpha=alpha)
+
+        plt.gca().annotate('Main Beam',
+                xy=(0.48,0.59),
+                xytext=(.2, .75), 
+                textcoords='figure fraction',
+                xycoords='figure fraction',
+                horizontalalignment='left', verticalalignment='top',
+                arrowprops=arrowprops,
+                color=color,
+                fontsize=10,
+                alpha=alpha,
+                )
+        plt.gca().annotate('Secondary Spillover',
+                xy=(0.49,0.51),
+                xytext=(.5, .75), 
+                textcoords='figure fraction',
+                xycoords='figure fraction',
+                horizontalalignment='left', verticalalignment='top',
+                arrowprops=arrowprops,
+                color=color,
+                alpha=alpha,
+                fontsize=10)
+        plt.gca().annotate('Primary Spillover',
+                xy=(0.43,0.27),
+                xytext=(.55, .55), 
+                textcoords='figure fraction',
+                xycoords='figure fraction',
+                horizontalalignment='left', verticalalignment='top',
+                arrowprops=arrowprops,
+                color=color,
+                alpha=alpha,
+                fontsize=10)
+        #print(m.shape, m1.shape)
+        plt.savefig(f"beam.pdf", pad_inches=0.0, transparent=True, dpi=300)
         plt.show()
 
-# %%
-import numpy as np
-import matplotlib.pyplot as plt
-import healpy as hp
-from cosmoglobe import plot
+    main(nside_planck=512)
 
-import h5py
-
-from sys import exit
-
-
-def real_2_alm(rlm, lmax, mmax):
-    cx_alm = np.zeros(mmax * (2 * lmax + 1 - mmax) // 2 + lmax + 1, dtype="complex")
-
-    for l in range(0, lmax):
-        for m in range(0, mmax):
-            if m > l:
-                continue
-            healpixI = hp.sphtfunc.Alm.getidx(lmax, l, m)
-            outI = getOutidx(l, m)
-            outJ = getOutidx(l, -1 * m)
-            if m == 0:
-                cx_alm[healpixI] = rlm[outI]
-            else:
-                cx_alm[healpixI] = (rlm[outI] + 1j * rlm[outJ]) / 2 ** 0.5
-
-    return cx_alm
-
-
-def getOutidx(l, m):
-    return l ** 2 + l + m
-
-
-def main(
-    rot=0, nside_planck=4096,
-):
-    # According to the BP overview paper, the Planck beams are normalized such that
-    # their integral combined is equal to unity.
-    path="./"
-    path="/Users/svalheim/work/workdir-thesis/beams/"
-    data = h5py.File(path+"LFI_instrument_v6.h5", "r")
-
-    blm = data["27S/beam/T"][...]
-    blmax = data["27S/beamlmax"][...]
-    bmmax = data["27S/beammmax"][...]
-
-    slm = data["27S/sl/T"][...]
-    slmax = data["27S/sllmax"][...]
-    smmax = data["27S/slmmax"][...]
-
-    cx_alm = real_2_alm(slm, slmax[0], smmax[0])
-    # s_lp = hp.alm2cl(cx_alm, lmax=slmax[0], mmax=smmax[0]) ** 0.5 * (4 * np.pi) ** 0.5
-    m = hp.alm2map(cx_alm, nside_planck, lmax=slmax[0], mmax=smmax[0])
-    m[m <= 0] = min(abs(m))
-
-    arcmin2rad=0.000290888
-    cx_alm = real_2_alm(blm, blmax[0], bmmax[0])
-    m1 = hp.alm2map(cx_alm, nside_planck, lmax=blmax[0], mmax=bmmax[0])
-    m1[m1 <=2e-2] = min(abs(m1))
-  
-    #hp.mollview(m,  rot=(0, 90, 0), norm="log", min=1e-5, max=5e-2, cmap="afmhot", title="27S Beam sidelobes")
-    #hp.mollview(m1, rot=(0, 90, 0), min=0,  cmap="afmhot", title="main beam")
-    #hp.gnomview(m1, rot=(0, 90, 0), reso=0.75, min=0, max=1, cmap="afmhot", title="Main beam")
-    #hp.mollview(m + m1, rot=(0, 90, 0), min=1e-5, max=1000, norm="log", cmap="afmhot", title="combined beams")
-    #plot(np.log10(m + m1), rot=(0, 90, 0), min=-5, max=3, cmap="afmhot",)
-    plot(m + m1, rot=(0, 90, 0), min=1e-5, max=5e-2,norm="log", cmap="afmhot",width="l")
-
-    #print(m.shape, m1.shape)
+"""
+TODO: 
+Check why log noisy, maybe force 0
+"""
+if True: #simplest
+    """
+    image, params = plot(path+dust, min=1e-1, max=1e2, width="l", sig="I", cmap="planck", cbar=False)#, norm=colors.SymLogNorm(linthresh=1, linscale=0.03, base=10))
+    """
+    dust = hp.read_map(path+dust, field=1)
+    cmb = hp.read_map(path+cmb)
+    """
+    hp.projview(dust, rlabel=r"A$_{\mathsf{dust}}$", llabel=r"$Q$", unit=r"$\mu$K", fontname="serif", min=-100, max=100, width=10, show_tickmarkers=True, cbar_ticks=[-100,-50, 0,50, 100], cb_orientation="vertical", sub=221, override_plot_properties={"cbar_tick_direction":"in"})
+    hp.projview(dust, norm="symlog", rlabel=r"A$_{\mathsf{dust}}$", llabel=r"$Q$", unit=r"$\mu$K", cbar_ticks=[-100,-50, 0,50, 100], remove_mono=True, show_tickmarkers=True,  cb_orientation="horizontal", sub=222, override_plot_properties={"cbar_tick_direction":"in"})
+    hp.projview(cmb,  rlabel=r"A$_{\mathrm{cmb}}$", llabel=r"$I$",  unit=r"$\mu$K",  min=-3e3, max=3e3,  cb_orientation="vertical", sub=223, graticule=True, )
+    hp.projview(cmb,  rlabel=r"A$_{\mathrm{cmb}}$", llabel=r"$I$", unit=r"$\mu$K", fontname="serif",  remove_dip=True, min=-300, max=300,  cb_orientation="horizontal", sub=224, graticule=True, rot_graticule=True, rot=(0,0,0))
+    plt.tight_layout()
+    plt.savefig("example.png", dpi=300)
+    """
+    plot(dust, comp="dust", norm="log", cb_orientation="vertical")
+    
+    #hp.projview(dust, graticule=True,  coord="E",min=-1e3, max=1e3, sub=223, override_plot_properties={"figure_width":20},cbar=True)
+    #hp.mollview(dust,min=-1e3, max=1e3, coord=["E"], sub=224, title="",cbar=True); 
     plt.show()
+    exit()
 
-main(nside_planck=2048)
-
-
-# %%
-
+    hp.mollview
 
 # %%
